==> irm_1.4.3.orig.tar.gz: irm-1.4.3/users/passwd.php <==
<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#    $Id: passwd.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
#
################################################################################
#                                  CHANGELOG                                   #
################################################################################
#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
################################################################################

include("../include/irm.inc");

AuthCheck("normal");

commonHeader("IRM - Change Password");
?>
To change your password, please fill in the form below:

<p>
<?php
PRINT "<form method=post action=\"$USERPREFIX/passwd-change.php\">";
?>
<table border=0>
<tr>
  <td>Old Password</td>
  <td><input type=password cols=10 name=oldpassword></td>
</tr>
<tr>
  <td>New Password</td>
  <td><input type=password cols=10 name=newpassword></td>
</tr>
<tr>
  <td>Confirm New Password</td>
  <td><input type=password cols=10 name=confirm></td>
</tr>
</table>
<input type=submit value="Change Password">
</form>
<?php
commonFooter();
?>

==> irm_1.5.3.1.orig.tar.gz: irm-1.5.3.1/users/passwd.php <==
<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
################################################################################

include("../include/irm.inc");
require_once 'include/i18n.php';
AuthCheck("normal");

commonHeader("Change Password");

__("To change your password, please fill in the form below:");
?>
<p>
<form method=post action="<?php echo Config::AbsLoc('users/passwd-change.php') ?>">
<table border=0>
<tr>
  <td><?php __("Old Password")?></td>
  <td><input type=password cols=10 name=oldpassword></td>
</tr>
<tr>
  <td><?php __("New Password")?></td>
  <td><input type=password cols=10 name=newpassword></td>
</tr>
<tr>
  <td><?php __("Confirm New Password")?></td>
  <td><input type=password cols=10 name=confirm></td>
</tr>
</table>
<input type=submit value="<?php __("Change Password")?>">
</form>
<?php
commonFooter();
